* ------------------------------------------------------------------------------
*
*           THE ECONOMICS OF WOMEN'S RIGHTS  - - Extended Data Set 
*                  
* ------------------------------------------------------------------------------
*
* by Michèle Tertilt, Matthias Doepke, Anne Hannusch and Laura Montenbruck
*
* This version: 2023-01-15
*
* This file creates variables for the analysis in Tertilt et al. (2022),
* but uses an updated and extended version of the raw data set
*
* Inpute files: WR_dataset.dta in subdirectory '../data/' - ADJUST AS FINAL STEP
* Output files: WR_finaldata.dta in subdirectory '../data/' - ADJUST AS FINAL STEP
*
* Notes:
* - To run the code, please adjust line 27 and line 30.
*
* ------------------------------------------------------------------------------

* Housekeeping
clear all
set more off

* ADJUST AS FINAL STEP: Adjust path to base directory 
*global basedirectory  "../ReplicationPackage"

* For Windows, change to "\"
*global SLASH "/"

* Relative paths to subdirectories
*global data 	"${basedirectory}${SLASH}data"
*global tables 	"${basedirectory}${SLASH}output${SLASH}tables${SLASH}"
*global figures	"${basedirectory}${SLASH}output${SLASH}figures${SLASH}"

* Load data
*use "${data}${SLASH}final_data.dta", clear

* --------------------------
* REMOVE AS FINAL STEP
global WR  "/Users/hannusch/Dropbox/ Research/Marshall Lecture/Data/A_FinalData/Women's Rights Replication 2023-01-23"
global data	"$WR/data"
 
use "$data/WR_dataset.dta", clear

cap log close
log using "$data/2_variables", replace


* ------------------------------------------------------------------------------
* A. Create independent variables 
* ------------------------------------------------------------------------------


* 1. Country ID
	encode country, gen(c_id) 
	label var country "Country ID"

	
* 2. GDP per capita in 1000s of 2015 USD
	gen gdp_pc=NY_GDP_PCAP_KD/1000
	label var gdp_pc "GDP p.c. (in 1000s)"
	
	
* 3. Female population share
	gen fem_pop_share=(100-SP_POP_TOTL_MA_ZS)	
	label var fem_pop_share "Female population share"
	
	
* 4. OPEC dummy
	* see https://www.opec.org/opec_web/en/about_us/25.htm
	* Members: Algeria, Angola, Congo, Equatorial Guinea, Gabon, Iran, Iraq, Kuwait, Libya, Nigeria, Saudi Arabia, United Arab Emirates and Venezuela
	gen 	OPEC=0
	replace OPEC=1 if 	country=="Algeria" | country=="Angola" | country=="Congo, Rep." | ///
						country=="Equatorial Guinea" | country=="Gabon" | country=="Iran, Islamic Rep." | ///
						country=="Iraq" | country=="Kuwait" | country=="Libya" | country=="Nigeria" | ///
						country=="Saudi Arabia" | country=="United Arab Emirates" | country=="Venezuela, RB"
	label var OPEC "OPEC"
	
	
* 5. Female LFP 15-64
*    Combine FLFP age 15-64 from World Development Indicators and ILO data and create flag
	gen missing_FLFP = missing(SL_TLF_ACTI_FE_ZS)

	gen FLFP_15_64=SL_TLF_ACTI_FE_ZS
	replace FLFP_15_64=FLFP_ilo_15_64 if FLFP_15_64==. & FLFP_ilo_15_64!=.
	label var FLFP_15_64 "Female LFP (15-64)"
	
	gen flfp_flag = 0 if FLFP_15_64!=.
	replace flfp_flag = 1 if missing_FLFP==1 & FLFP_15_64!=.
	
	label var flfp_flag "Allocation flag FLFP 15-64"
	label define flfp_flag_val 0 "ILO data" 1 "WDI data"
	label val flfp_flag flfp_flag_val	
	
	
* 6. Religion shares and majority religion dummies

* 	6.1 Muslim
	gen share_muslim=0
	replace share_muslim=share_muslim+muslim if muslim>0 & muslim<.
	replace share_muslim=share_muslim+shia if shia>0 & shia<.
	replace share_muslim=share_muslim+sunni if sunni>0 & sunni<.
	replace share_muslim=share_muslim/100

	gen majority_muslim=0
	replace majority_muslim=1 if share_muslim>=0.5 & share_muslim<.
 
* 	6.2 Catholic 
	gen share_catholic=0
	replace share_catholic=share_catholic+romancatholic if romancatholic>0 & romancatholic<.
	replace share_catholic=share_catholic/100
	
	gen majority_catholic=0
	replace majority_catholic=1 if share_catholic>=0.5 & share_catholic<.
	
* 	6.3 Buddhist
	gen share_buddhist=0
	replace share_buddhist=share_buddhist+buddhist if buddhist>0 & buddhist<.
	replace share_buddhist=share_buddhist+hindu if hindu>0 & hindu<.
	replace share_buddhist=share_buddhist/100
	
	gen majority_buddhist=0
	replace majority_buddhist=1 if share_buddhist>=0.5 & share_buddhist<.
	
* 	6.4 Replace missing obervations with "." in religious shares
	gen missings=0
	replace missings=1 if other==. & shia==. &	sunni==. & muslim==. & orthodox==. & romancatholic==. &	///
	christian==. & protestant==. & traditionalbelief==. & jewish==. & yezidi==. & buddhist==. & ///
	hindu==. & bahai==. & sikh==. & nonreligious==. & coptic==. & jain==. & zoroastrian==. & ///
	druze==. & ibadiyah==. & taoism==. & chondogyo==. & confucian==. & wonbulgyo==. & ikuantao==. & ///
	caodai==. & hoahoa==.  
		
	foreach var of varlist share_muslim majority_muslim share_buddhist majority_buddhist ///
		share_catholic majority_catholic{  
		replace `var'=. if missings==1
	}

* 	6.5 Extend religious majorities beyond 2013: 
*       Idea: If majority did not change between 2010 and 2013 (last 5 years), extend majority until end of sample

* 	NOTE: The original data comes from the CREG project at the University of Illinois. The center currently
*         works on updating the data beyond 2013. Please check the link to see whether the updated data is available:
*         https://clinecenter.illinois.edu/project/Religious-Ethnic-Identity/composition-religious-and-ethnic-groups-creg-project
*         When working with the updated data, the following variable extension (line 135-170) is no longer necessary.

	local rel muslim catholic buddhist
	sort country year
	foreach x of local rel {
		* How often is a year-specific dummy equal to the value in the previous year?
		bysort country: gen same_`x'=1 if majority_`x'==majority_`x'[_n-1] & year>=2010 & year<=2013 & majority_`x'!=.
		bysort country: egen all_same_`x'=sum(same_`x') 
	}
	
	* Are religious majorities constant between 2010 and 2013?
	gen all_same_all_rel= all_same_muslim+all_same_catholic+all_same_buddhist

	sort country year
	foreach x of local rel {
		* If yes: Extend dummies for religious majorities beyond 2013
		bysort country: replace majority_`x'=majority_`x'[_n-1] if all_same_all_rel==12 & year>2013
		* Create flag for replaced values
		gen majority_`x'_flag = 0 if majority_`x'!=.
		replace majority_`x'_flag = 1 if majority_`x'!=. & year>2013
		label define majority_`x'_val 0 "Not allocated" 1 "Allocated"
		label val majority_`x'_flag majority_`x'_val
	}
	
	drop same_* all_same_*
	
	label var majority_muslim 	"Majority Muslim"
	label var majority_catholic "Majority Catholic"
	label var majority_buddhist "Majority Buddhist"	
	
	label var majority_muslim_flag 	"Allocation flag Muslim majority"
	label var majority_catholic_flag "Allocation flag Catholic majority"
	label var majority_buddhist_flag "Allocation flag Buddhist majority"	
	
	
* 7. Extension of independence variable 
*    & flag that indicates replaced values
*    For data sources, see Appendix starting at line 385

	gen missing_independence=1 if missing(independence)

	bysort country: replace independence = 0 if missing(independence)
	
	replace independence = 1 if wbcodev2=="CAN" & year==1982 // Canada (full independence from the UK)
	replace independence = 1 if wbcodev2=="GRD" & year==1974 // Grenada
	replace independence = 1 if wbcodev2=="XKX" & year==2008 // Kosovo
	replace independence = 1 if wbcodev2=="FSM" & year==1986 // Micronesia, Fed. Sts.
	replace independence = 1 if (wbcodev2=="MNE" | wbcodev2=="SRB") & year==1991 // Serbia and Montenegro emerge from former Yugoslavia
	replace independence = 1 if (wbcodev2=="MNE" | wbcodev2=="SRB") & year==2003 // Serbia and Montenegro
    replace independence = 1 if (wbcodev2=="MNE" | wbcodev2=="SRB") & year==2006 // Independence between Serbia and Montenegro
	replace independence = 1 if wbcodev2=="MOZ" & year==1975 // Mozambique
	replace independence = 1 if wbcodev2=="MKD" & year==1991 // North Macedonia
	replace independence = 1 if wbcodev2=="RUS" & year==1991 // Russia (former Soviet Union)
	replace independence = 1 if wbcodev2=="SVN" & year==1991 // Slovenia  
	replace independence = 1 if wbcodev2=="SSD" & year==2011 // South Sudan
	replace independence = 1 if wbcodev2=="TLS" & year==2002 // East Timor	 
	replace independence = 1 if wbcodev2=="ZWE" & year==1980 // Zimbabwe
		
	replace independence = 1 if wbcodev2=="VNM" & year==1976 // Reunification of North & South Vietnam
   
	label var independence "Indicator Year of Independence"
   
	gen independence_flag = 0 if independence!=.
	replace independence_flag = 1 if missing_independence==1 & independence!=.
	
	label var independence_flag "Allocation flag Year of Independence"
	label define independence_flag_val 0 "Not allocated" 1 "Allocated"
	label val independence_flag independence_flag_val


* 8. International pressure
	bys year region: egen ratifications_regional = mean(Contotal)
	label var ratifications_regional "International pressure"
	
	
* ------------------------------------------------------------------------------
* B. Create dependent variables: Indices of women's rights
* ------------------------------------------------------------------------------


* 1. Political Rights subindex: Right to be elected (universal stand)  
	gen univ_stand_women=.
	replace univ_stand_women=0 if univstand==9999
	replace univ_stand_women=0 if univstand>year & univstand!=9999 & univstand!=.
	replace univ_stand_women=1 if univstand<1945 & univstand!=9999 & univstand!=.
	replace univ_stand_women=1 if univstand<=year & year<=2003	
 
	label var univ_stand_women "Right to be elected"

	* 1.1 Extend right to be elected beyond 2003
	*     & create flag that indicates replaced values
	
	gen missing_univ_stand=1 if missing(univ_stand_women)
	
	sort c_id year
	bysort c_id: replace univ_stand_women = univ_stand_women[_n-1] if missing(univ_stand_women) & year>2003
		 
	replace univ_stand_women = 0 if univ_stand_women==. & ///
			(wbcodev2=="ARE" | wbcodev2=="KWT" | wbcodev2=="MNE" | wbcodev2=="QAT" | ///
			 wbcodev2=="SAU" | wbcodev2=="SSD" | wbcodev2=="TLS" | wbcodev2=="XKX" | ///
			 wbcodev2=="BRN" | wbcodev2=="MDA" | wbcodev2=="MKD")
		
	replace univ_stand_women = 1 if wbcodev2=="ARE" & year>=2005 // United Arab Emirates
	replace univ_stand_women = 1 if wbcodev2=="KWT" & year>=2005 // Kuwait
    replace univ_stand_women = 1 if wbcodev2=="MNE" & year>=2006 // Montenegro
    replace univ_stand_women = 1 if wbcodev2=="QAT" & year>=2003 // Qatar
    replace univ_stand_women = 1 if wbcodev2=="SAU" & year>=2015 // Saudi Arabia
    replace univ_stand_women = 1 if wbcodev2=="SSD" & year>=2011 // South Sudan
    replace univ_stand_women = 1 if wbcodev2=="TLS" & year>=2001 // East Timor 
    replace univ_stand_women = 1 if wbcodev2=="XKX" & year>=2008 // Kosovo
	replace univ_stand_women = 0 if wbcodev2=="BRN" & year>=2004 // Brunei; no right to stand for elections (up to 2022)
    replace univ_stand_women = 0 if wbcodev2=="MDA" & year<1991  // Moldova
    replace univ_stand_women = 1 if wbcodev2=="MDA" & year>=1991 // Moldova
    replace univ_stand_women = 0 if wbcodev2=="MKD" & year<1991  // North Macedonia
    replace univ_stand_women = 1 if wbcodev2=="MKD" & year>=1991 // North Macedonia	

	gen univ_stand_women_flag = 0 if univ_stand_women!=.
	replace univ_stand_women_flag = 1 if missing_univ_stand==1 & univ_stand_women!=.
	
	label var univ_stand_women_flag "Allocation flag Women in parliament"
	label define univ_stand_women_flag_val 0 "Not allocated" 1 "Allocated"
	label val univ_stand_women_flag univ_stand_women_flag_val	


* 2. Political Rights subindex: Women in parliament - Percentage ever above 20 %
	gen parliament_p20=.
	replace parliament_p20=0 if thresh20==9999
	replace parliament_p20=0 if thresh20>year & thresh20!=9999
	replace parliament_p20=1 if thresh20<=year & year<=2003
	replace parliament_p20=. if year>2003

*   2.1 Extend women in parliament using WDI data and create flag
	
	clonevar parliament_p20_comb=parliament_p20									// clone threshold dummy
	bysort country: egen max_p20=max(parliament_p20)							// generate max (if ever passed threshold)
	clonevar y20=year															// clone year variable
	replace y20=. if SG_GEN_PARL_ZS<=20 | SG_GEN_PARL_ZS==.						// replace year=. if this year's share is smaller than threshold of interest or missing
	bysort country: egen t_passed_20=min(y20)									// generate year when threshold was first passed based on WDI data (after 2003)						
	replace parliament_p20_comb=1 if year>=t_passed_20							// replace threshold with 1 anytime after this year
	replace parliament_p20_comb=0 if year<t_passed_20 & year>2003 & SG_GEN_PARL_ZS!=.

	gen missing_parliament_p20=1 if parliament_p20==.

	gen parliament_p20_comb_flag = 0 if parliament_p20_comb!=.
	replace parliament_p20_comb_flag = 1 if missing_parliament_p20==1 & parliament_p20_comb!=.
	
	label var parliament_p20_comb_flag "Allocation flag Women in parliament"
	label define parliament_p20_comb_flag_val 0 "Not allocated" 1 "Allocated"
	label val parliament_p20_comb_flag parliament_p20_comb_flag_val		
	
	
*   2.2 Only after 2003, use WDI data
	* Keep missing values if threshold hasn't clearly been surpassed 
	replace parliament_p20_comb=1 if year>2003 & max_p20==1 					// for every country that has surpassed the threshold by 2003, set indicator to one afterwards
		
	* If missing and univ_stand_women==0, then recode to 0
	replace parliament_p20_comb=0 if parliament_p20_comb==. & univ_stand_women==0
	label var parliament_p20_comb "Women in parliament $>$20\%"	
	

* 3. Body Rights subindex: Contraceptive prevalence 
	gen contr_prev=.
	qui sum contraception_married
	replace contr_prev=0 if contraception_married<r(mean) 
	replace contr_prev=1 if contraception_married>=r(mean) & contraception_married<.
	label var contr_prev "Contraceptive prevalence"
 	
	
* 4. Body Rights subindex: Extend Abortion indices from Boyle et al. (2015) beyond 2009
	replace lifen    = reason_1 if year == 2011 | year == 2013 | year == 2015 | year == 2017 // To save a woman's life
	replace phealthn = reason_2 if year == 2011 | year == 2013 | year == 2015 | year == 2017 // To preserve a woman's physical health
	replace mhealthn = reason_3 if year == 2011 | year == 2013 | year == 2015 | year == 2017 // To preserve a woman's mental health
	replace rapen    = reason_4 if year == 2011 | year == 2013 | year == 2015 | year == 2017 // In case of rape or incest
	replace foetaln  = reason_5 if year == 2011 | year == 2013 | year == 2015 | year == 2017 // Because of foetal impairment
	replace econsocn = reason_6 if year == 2011 | year == 2013 | year == 2015 | year == 2017 // For economic or social reasons
	replace demandn  = reason_7 if year == 2011 | year == 2013 | year == 2015 | year == 2017 // On request

*   4.1 Interpolate between observations
	sort c_id year
	foreach var of varlist lifen phealthn mhealthn rapen foetaln econsocn demandn{
		gen missing_`var'=1  if missing(`var') & year==2010 | year==2012 | year==2014 | year==2016
		by c_id: replace `var'= `var'[_n-1] if year==2010 | year==2012 | year==2014 | year==2016

	}
	
	gen abortion_idx_1 = 0
	replace abortion_idx_1 = 1 if lifen==1 | phealthn==1
	replace abortion_idx_1 = . if lifen==. & phealthn==.
	label var abortion_idx_1 "Abortion rights to preserve woman's physical health"
	
	gen abortion_idx_1_flag = 0 if abortion_idx_1!=. 
	replace abortion_idx_1_flag = 1 if abortion_idx_1!=. & missing_lifen==1 & missing_phealthn==1
	label var abortion_idx_1_flag "Allocation flag Abortion index 1"
	label define abortion_idx_1_flag_val 0 "Not allocated" 1 "Allocated"
	label val abortion_idx_1_flag abortion_idx_1_flag_val
	
	gen abortion_idx_2 = 0
	replace abortion_idx_2 = 1 if mhealthn==1 | rapen==1| foetaln==1| econsocn==1| demandn==1
	replace abortion_idx_2 = . if mhealthn==. & rapen==.& foetaln==.& econsocn==.& demandn==.
	label var abortion_idx_2 "Abortion rights for reasons other than preserving physical health"

	gen abortion_idx_2_flag = 0 if abortion_idx_2!=. 
	replace abortion_idx_2_flag = 1 if abortion_idx_2!=. & missing_mhealthn==1 & ///
	missing_rapen==1 & missing_foetaln==1 & missing_econsocn==1 & missing_demandn==1
	label var abortion_idx_2_flag "Allocation flag Abortion index 2"
	label define abortion_idx_2_flag_val 0 "Not allocated" 1 "Allocated"
	label val abortion_idx_2_flag abortion_idx_2_flag_val
	
	
* 5. Economic Rights Index
	gen Economic_rights=.
	replace Economic_rights=(gr1_1passpmrd+gr1_2trvlctrymrd+gr1_3trvlhmmrd+gr1_4whlivemrd+ ///
	gr4_13obeymrd+gr4_14hhmrd+gr4_16dvrcjdgmnt+gr4_17equalremarr+gr6_23cntrcthmmrd+ ///
	gr6_24regbusmrd+gr6_25bnkaccmrd+gr6_26disgend+gr7_27prtyeqownmrdbth+gr7_28prtyeqsondght+ /// 
	gr7_29prtyeqsuvrspse+gr7_30prtylegadmin)/16*100

	label var Economic_rights 	"Economic Rights Index"	
	
* 6. Political Rights Index
	gen Political_rights=.
	replace Political_rights=(female_suffrage+univ_stand_women+parliament_p20_comb)/3*100 

	label var Political_rights 	"Political Rights Index"	
	
* 7. Labor Rights Index
	gen Labor_rights=.
	replace Labor_rights=(gr2_5profhmmrd+gr2_6nondiscempl+gr3_9eqremunval+gr3_10nprgeqnight+gr3_11jobshazard+gr3_12industry)/6*100

	label var Labor_rights 		"Labor Rights Index"

* 8. Body Rights Index
	gen Body_rights=.
	replace Body_rights=(gr2_7sexhrssemp+gr2_8sexcomb+gr4_15domleg+abortion_idx_1+abortion_idx_2+contr_prev)/6*100

	label var Body_rights 		"Body Rights Index"
		
* 9. Overall Rights Index
	gen Overall_rights=.
	replace Overall_rights = (gr1_1passpmrd+gr1_2trvlctrymrd+gr1_3trvlhmmrd+gr1_4whlivemrd+ ///
	gr4_13obeymrd+gr4_14hhmrd+gr4_16dvrcjdgmnt+gr4_17equalremarr+gr6_23cntrcthmmrd+gr6_24regbusmrd+ ///
	gr6_25bnkaccmrd+gr6_26disgend+gr7_27prtyeqownmrdbth+gr7_28prtyeqsondght+gr7_29prtyeqsuvrspse+ ///
	gr7_30prtylegadmin) + /// Economic rights
	(female_suffrage)+ /// Political rights (excl. univ_stand_women and parliament_p20_comb)
	(gr2_5profhmmrd+gr2_6nondiscempl+gr3_9eqremunval+gr3_10nprgeqnight+gr3_11jobshazard+ ///
	gr3_12industry) + /// Labor Rights
	(gr2_7sexhrssemp+gr2_8sexcomb+gr4_15domleg+contr_prev) // Body rights (excl. abortion rights index A1 and A2)
	replace Overall_rights=Overall_rights/27*100

	label var Overall_rights 		"Overall Rights Index"


* ------------------------------------------------------------------------------
* C. Save final data
* ------------------------------------------------------------------------------

keep year c_id wbcodev2 country WBL_index Overall_rights Economic_rights /// Overall indices
Political_rights Labor_rights Body_rights ///
female_suffrage female_suffrage_flag univ_stand_women univ_stand_women_flag /// Subindices
parliament_p20_comb parliament_p20_comb_flag contr_prev abortion_idx_1 ///
abortion_idx_1_flag abortion_idx_2 abortion_idx_2_flag ///
gr6_23cntrcthmmrd gr1_1passpmrd gr3_10nprgeqnight gr3_12industry gr4_15domleg ///
gdp_pc SP_DYN_TFRT_IN  fem_pop_share FLFP_15_64 flfp_flag SL_AGR_EMPL_ZS /// independent variables
SE_SEC_ENRR wmningo Contotal region  OPEC  majority_muslim majority_muslim_flag ///
majority_catholic majority_catholic_flag majority_buddhist majority_buddhist_flag ///
ratifications_regional wbgi_gee independence independence_flag incomegroup            

order year c_id wbcodev2 country WBL_index Overall_rights Economic_rights /// Overall indices
Political_rights Labor_rights Body_rights ///
female_suffrage female_suffrage_flag univ_stand_women univ_stand_women_flag /// Subindices
parliament_p20_comb parliament_p20_comb_flag contr_prev abortion_idx_1 ///
abortion_idx_1_flag abortion_idx_2 abortion_idx_2_flag ///
gr6_23cntrcthmmrd gr1_1passpmrd gr3_10nprgeqnight gr3_12industry gr4_15domleg ///
gdp_pc SP_DYN_TFRT_IN  fem_pop_share FLFP_15_64 flfp_flag SL_AGR_EMPL_ZS /// independent variables
SE_SEC_ENRR wmningo Contotal region  OPEC  majority_muslim majority_muslim_flag ///
majority_catholic majority_catholic_flag majority_buddhist majority_buddhist_flag ///
ratifications_regional wbgi_gee independence independence_flag incomegroup       

label var c_id 		"Country"
label var year 		"Year"

rename SP_DYN_TFRT_IN tfr
rename FLFP_15_64 flfp
rename SE_SEC_ENRR sec_school_enroll
rename SL_AGR_EMPL_ZS emp_agriculture
rename wbgi_gee gov_eff
rename Contotal conventions
rename wmningo women_ingo
rename OPEC opec
 
rename gr6_23cntrcthmmrd wbl_signcontract
rename gr1_1passpmrd wbl_obtainpassport
rename gr3_10nprgeqnight wbl_workatnight
rename gr3_12industry wbl_workanyindustry 
rename gr4_15domleg wbl_domesticviolence 
 
save "$data/WR_finaldata.dta", replace

log close

* ------------------------------------------------------------------------------
* 									APPENDIX
* ------------------------------------------------------------------------------


* Data sources extension of universal right to stand for election after 2003:

// United Arab Emirates: https://data.ipu.org/compare?field=country%3Afield_stand_for_election%3Afield_right_to_vote#map
// Kuwait: https://data.ipu.org/compare?field=country%3Afield_stand_for_election%3Afield_right_to_vote#map
// Montenegro: https://www.google.com/url?sa=t&rct=j&q=&esrc=s&source=web&cd=&ved=2ahUKEwiC2OTv7qf5AhWKyqQKHfUGDgUQFnoECAkQAQ&url=https%3A%2F%2Fwww.emim.org%2Fimages%2Fpublikacije%2FZene-u-Skupstini-Crne-Gore-ENG.pdf&usg=AOvVaw24JhCzPri6zFjpVXyMK9Et
// Qatar: https://data.ipu.org/compare?field=country%3Afield_stand_for_election%3Afield_right_to_vote#map
// Saudi Arabia: https://www.theguardian.com/world/2011/sep/25/saudi-women-right-to-vote ; https://time.com/4130387/saudi-arabia-municipal-elections-women/ 
// South Sudan: http://sswen.org/wp-content/uploads/2018/01/Women-Political-Participation-.pdf
// East Timor: https://etan.org/etan/obproject/docs/women.htm 
// Kosovo: https://eca.unwomen.org/sites/default/files/Field%20Office%20ECA/Attachments/Publications/Country/Kosovo/AGE%20Raport%20Oct%202014.pd f (p. 126) As part of Yugoslavia: formal recognition of women's right to be elected since 1946 http://archive.ipu.org/PDF/publications/women45-95_en.pdf (Historical Table 1 p. 26)
// Brunei; no right to stand for elections up to now (2022): https://thescoop.co/2021/03/19/women-should-be-able-to-become-village-heads/
// Moldova: http://archive.ipu.org/PDF/publications/women45-95_en.pdf, p. 187 
// North Macedonia: https://www.wfd.org/sites/default/files/2022-02/Women%20Political%20Participation%202019%20EN%20for%20web%20%5B%5D.pdf

* Data sources for extension of independence variable :

// Canada: https://www.britannica.com/event/Canada-Act
// Grenada: https://www.britannica.com/place/Grenada
// Kosovo: https://www.britannica.com/place/Kosovo
// Micronesia, Fed. Sts.: https://www.britannica.com/place/Micronesia-republic-Pacific-Ocean
// Serbia and Montenegro / Yugoslavia: https://www.britannica.com/place/Montenegro
// Mozambique: https://www.britannica.com/place/Mozambique
// North Macedonia: https://www.britannica.com/place/North-Macedonia
// Russia: https://www.britannica.com/place/Soviet-Union
// Slovenia: https://www.britannica.com/place/Slovenia
// South Sudan: https://www.usip.org/programs/independence-south-sudan
// East Timor: https://www.britannica.com/place/East-Timor
// Zimbabwe: https://www.britannica.com/place/Zimbabwe


* ------------------------------------------------------------------------------
* 								end of do-file
* ------------------------------------------------------------------------------
